# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.msp.spark.v1alpha1 import session_pb2 as nebius_dot_msp_dot_spark_dot_v1alpha1_dot_session__pb2
from nebius.api.nebius.msp.spark.v1alpha1 import session_service_pb2 as nebius_dot_msp_dot_spark_dot_v1alpha1_dot_session__service__pb2


class SessionServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/nebius.msp.spark.v1alpha1.SessionService/Get',
                request_serializer=nebius_dot_msp_dot_spark_dot_v1alpha1_dot_session__service__pb2.GetSessionRequest.SerializeToString,
                response_deserializer=nebius_dot_msp_dot_spark_dot_v1alpha1_dot_session__pb2.Session.FromString,
                )
        self.GetByName = channel.unary_unary(
                '/nebius.msp.spark.v1alpha1.SessionService/GetByName',
                request_serializer=nebius_dot_msp_dot_spark_dot_v1alpha1_dot_session__service__pb2.GetSessionByNameRequest.SerializeToString,
                response_deserializer=nebius_dot_msp_dot_spark_dot_v1alpha1_dot_session__pb2.Session.FromString,
                )
        self.List = channel.unary_unary(
                '/nebius.msp.spark.v1alpha1.SessionService/List',
                request_serializer=nebius_dot_msp_dot_spark_dot_v1alpha1_dot_session__service__pb2.ListSessionsRequest.SerializeToString,
                response_deserializer=nebius_dot_msp_dot_spark_dot_v1alpha1_dot_session__service__pb2.ListSessionsResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/nebius.msp.spark.v1alpha1.SessionService/Create',
                request_serializer=nebius_dot_msp_dot_spark_dot_v1alpha1_dot_session__service__pb2.CreateSessionRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/nebius.msp.spark.v1alpha1.SessionService/Delete',
                request_serializer=nebius_dot_msp_dot_spark_dot_v1alpha1_dot_session__service__pb2.DeleteSessionRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )


class SessionServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Get(self, request, context):
        """Returns the specified session.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetByName(self, request, context):
        """Returns the specified session by name.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves a list of sessions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a session.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes a session.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SessionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=nebius_dot_msp_dot_spark_dot_v1alpha1_dot_session__service__pb2.GetSessionRequest.FromString,
                    response_serializer=nebius_dot_msp_dot_spark_dot_v1alpha1_dot_session__pb2.Session.SerializeToString,
            ),
            'GetByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetByName,
                    request_deserializer=nebius_dot_msp_dot_spark_dot_v1alpha1_dot_session__service__pb2.GetSessionByNameRequest.FromString,
                    response_serializer=nebius_dot_msp_dot_spark_dot_v1alpha1_dot_session__pb2.Session.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=nebius_dot_msp_dot_spark_dot_v1alpha1_dot_session__service__pb2.ListSessionsRequest.FromString,
                    response_serializer=nebius_dot_msp_dot_spark_dot_v1alpha1_dot_session__service__pb2.ListSessionsResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=nebius_dot_msp_dot_spark_dot_v1alpha1_dot_session__service__pb2.CreateSessionRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=nebius_dot_msp_dot_spark_dot_v1alpha1_dot_session__service__pb2.DeleteSessionRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nebius.msp.spark.v1alpha1.SessionService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SessionService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.msp.spark.v1alpha1.SessionService/Get',
            nebius_dot_msp_dot_spark_dot_v1alpha1_dot_session__service__pb2.GetSessionRequest.SerializeToString,
            nebius_dot_msp_dot_spark_dot_v1alpha1_dot_session__pb2.Session.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.msp.spark.v1alpha1.SessionService/GetByName',
            nebius_dot_msp_dot_spark_dot_v1alpha1_dot_session__service__pb2.GetSessionByNameRequest.SerializeToString,
            nebius_dot_msp_dot_spark_dot_v1alpha1_dot_session__pb2.Session.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.msp.spark.v1alpha1.SessionService/List',
            nebius_dot_msp_dot_spark_dot_v1alpha1_dot_session__service__pb2.ListSessionsRequest.SerializeToString,
            nebius_dot_msp_dot_spark_dot_v1alpha1_dot_session__service__pb2.ListSessionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.msp.spark.v1alpha1.SessionService/Create',
            nebius_dot_msp_dot_spark_dot_v1alpha1_dot_session__service__pb2.CreateSessionRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.msp.spark.v1alpha1.SessionService/Delete',
            nebius_dot_msp_dot_spark_dot_v1alpha1_dot_session__service__pb2.DeleteSessionRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
